@@ -21,6 +21,9 @@
 #' @import shiny
 
 jsSurveyGadget <- function(data, nfactor.limit = 20) {
+  requireNamespace("survival")
+  requireNamespace("survC1")
+  options(survey.lonely.psu = "certainty")
 
   out <- data.table(data, check.names = F)
   name.old <- names(out)
@@ -90,7 +93,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
                               tabPanel("Linear",
                                        sidebarLayout(
                                          sidebarPanel(
-                                           GEEModuleUI("linear")
+                                           regressModuleUI("linear")
                                          ),
                                          mainPanel(
                                            withLoader(DTOutput("lineartable"), type="html", loader="loader6")
@@ -100,7 +103,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
                               tabPanel("Binomial",
                                        sidebarLayout(
                                          sidebarPanel(
-                                           GEEModuleUI("logistic")
+                                           regressModuleUI("logistic")
                                          ),
                                          mainPanel(
                                            withLoader(DTOutput("logistictable"), type="html", loader="loader6")
@@ -428,7 +431,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
     })
 
 
-    out_ggpairs <- callModule(ggpairsModule2, "ggpairs", data = data, data_label = data.label, data_varStruct = NULL)
+    out_ggpairs <- callModule(ggpairsModule2, "ggpairs", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
 
     output$ggpairs_plot <- renderPlot({
       print(out_ggpairs())
@@ -441,7 +444,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
     })
 
 
-    out_roc <- callModule(rocModule, "roc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey)
+    out_roc <- callModule(rocModule, "roc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
 
     output$plot_roc <- renderPlot({
       print(out_roc()$plot)
@@ -455,7 +458,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
 
 
 
-    out_timeroc <- callModule(timerocModule, "timeroc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey)
+    out_timeroc <- callModule(timerocModule, "timeroc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
 
     output$plot_timeroc <- renderPlot({
       print(out_timeroc()$plot)
@@ -477,7 +480,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
 
 
 
-#' @title jsSurveydAddin: Rstudio addin of jsSurveyGadget
+#' @title jsSurveyAddin: Rstudio addin of jsSurveyGadget
 #' @description Rstudio addin of jsSurveyGadget
 #' @return Rstudio addin of jsSurveyGadget
 #' @details Rstudio addin of jsSurveyGadget
@@ -487,12 +490,12 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
 #'  }
 #' @seealso
 #'  \code{\link[rstudioapi]{rstudio-editors}}
-#' @rdname jsSurveydAddin
+#' @rdname jsSurveyAddin
 #' @export
 #' @importFrom rstudioapi getActiveDocumentContext
 
 
-jsSurveydAddin <- function(){
+jsSurveyAddin <- function(){
   context <- rstudioapi::getActiveDocumentContext()
   # Set the default data to use based on the selection.
   dataString <- context$selection[[1]]$text
@@ -500,3 +503,329 @@ jsSurveydAddin <- function(){
   #viewer <- dialogViewer("Subset", width = 1000, height = 800)
   jsSurveyGadget(data, nfactor.limit = 20)
 }
+
+
+
+
+#' @title jsSurveyExtAddin: RStudio Addin for survey data analysis with external data.
+#' @description RStudio Addin for survey data analysis with external csv/xlsx/sas7bdat/sav/dta file.
+#' @param nfactor.limit nlevels limit for categorical variables, Default: 20
+#' @param max.filesize Maximum file size to upload (MB), Default: 2048 (2 GB)
+#' @return RStudio Addin for survey data analysis with external data.
+#' @details RStudio Addin for survey data analysis with external csv/xlsx/sas7bdat/sav/dta file.
+#' @examples
+#' if(interactive()){
+#'  jsSurveyExtAddin()
+#'  }
+#' @seealso
+#'  \code{\link[data.table]{fwrite}}
+#'  \code{\link[jstable]{opt.tb1}},\code{\link[jstable]{opt.tbreg}}
+#' @rdname jsSurveyExtAddin
+#' @export
+#' @importFrom data.table fwrite
+#' @importFrom jstable opt.tb1 opt.tbreg
+#' @importFrom DT datatable %>% formatStyle styleEqual renderDT DTOutput
+#' @importFrom shinycustomloader withLoader
+#' @importFrom jstable opt.data opt.tb1 opt.tbreg
+#' @importFrom utils data
+#' @import shiny
+
+
+jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048){
+
+  data.example <- utils::data("nhanes", package = "survey")
+  options(shiny.maxRequestSize = max.filesize * 1024^2, survey.lonely.psu = "certainty")
+
+  ui <- navbarPage("Survey data analysis",
+                   tabPanel("Data",
+                            sidebarLayout(
+                              sidebarPanel(
+                                uiOutput("import"),
+                                downloadButton("downloadData", "Example data")
+                              ),
+                              mainPanel(
+                                tabsetPanel(type = "pills",
+                                            tabPanel("Data", withLoader(DTOutput("data"), type="html", loader="loader6")),
+                                            tabPanel("Label", withLoader(DTOutput("data_label", width = "100%"), type="html", loader="loader6"))
+                                ),
+                                htmlOutput("naomit")
+
+                              )
+                            )
+                   ),
+                   tabPanel("Table 1",
+                            sidebarLayout(
+                              sidebarPanel(
+                                tb1moduleUI("tb1")
+                              ),
+                              mainPanel(
+                                tabsetPanel(type = "pills",
+                                            tabPanel("Unweighted",
+                                                     withLoader(DTOutput("untable1"), type="html", loader="loader6"),
+                                                     wellPanel(
+                                                       h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
+                                                       h5("Non-normal continuous variables are summarized with median [IQR] and kruskal-wallis test"),
+                                                       h5("Categorical variables  are summarized with table")
+                                                     )
+                                            ),
+                                            tabPanel("Weighted",
+                                                     withLoader(DTOutput("table1"), type="html", loader="loader6"),
+                                                     wellPanel(
+                                                       h5("Normal continuous variables  are summarized with Mean (SD) and complex survey regression"),
+                                                       h5("Non-normal continuous variables are summarized with median [IQR] and complex sampling rank test"),
+                                                       h5("Categorical variables  are summarized with table and svychisq test")
+                                                     )
+                                            )
+                                )
+
+                              )
+                            )
+                   ),
+                   navbarMenu("Survey regression",
+                              tabPanel("Linear",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           regressModuleUI("linear")
+                                         ),
+                                         mainPanel(
+                                           withLoader(DTOutput("lineartable"), type="html", loader="loader6")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Binomial",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           regressModuleUI("logistic")
+                                         ),
+                                         mainPanel(
+                                           withLoader(DTOutput("logistictable"), type="html", loader="loader6")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Cox model",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           coxUI("cox")
+                                         ),
+                                         mainPanel(
+                                           withLoader(DTOutput("coxtable"), type="html", loader="loader6")
+                                         )
+                                       )
+                              )
+
+                   ),
+                   navbarMenu("Plot",
+                              tabPanel("Scatter plot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           ggpairsModuleUI1("ggpairs")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("ggpairs_plot"), type="html", loader="loader6"),
+                                           ggpairsModuleUI2("ggpairs")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Kaplan-meier plot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           kaplanUI("kaplan")
+                                         ),
+                                         mainPanel(
+                                           optionUI("kaplan"),
+                                           withLoader(plotOutput("kaplan_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("kaplan")
+                                         )
+                                       )
+                              )
+
+                   ),
+                   navbarMenu("ROC analysis",
+                              tabPanel("ROC",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           rocUI("roc")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("plot_roc"), type="html", loader="loader6"),
+                                           ggplotdownUI("roc"),
+                                           withLoader(DTOutput("table_roc"), type="html", loader="loader6")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Time-dependent ROC",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           timerocUI("timeroc")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("plot_timeroc"), type="html", loader="loader6"),
+                                           ggplotdownUI("timeroc"),
+                                           withLoader(DTOutput("table_timeroc"), type="html", loader="loader6")
+                                         )
+                                       )
+                              )
+                   )
+  )
+
+
+
+
+  server <- function(input, output, session) {
+
+
+    output$downloadData <- downloadHandler(
+      filename = function() {
+        paste("example_survey", ".csv", sep = "")
+      },
+      content = function(file) {
+        data.table::fwrite(get(data.example), file)
+      }
+    )
+
+    output$import <- renderUI({
+      FileSurveyInput("datafile")
+
+    })
+
+    data.info <- callModule(FileSurvey, "datafile", nfactor.limit = nfactor.limit)
+    data <- reactive(data.info()$data)
+    data.label <- reactive(data.info()$label)
+    id.weight.survey <- reactive(data.info()$id.weight.survey)
+    design.survey <- reactive(data.info()$survey)
+
+    output$data <- renderDT({
+      datatable(data(), rownames=F, editable = F, extensions= "Buttons", caption = "Data",
+                options = c(opt.data("data"), list(scrollX = TRUE))
+      )
+    })
+
+
+    output$data_label <- renderDT({
+      datatable(data.label(), rownames=F, editable = F, extensions= "Buttons", caption = "Label of data",
+                options = c(opt.data("label"), list(scrollX = TRUE))
+      )
+    })
+
+    output$naomit <- renderText({
+      data.info()$naomit
+    })
+
+
+    out_untb1 <- callModule(tb1module2, "tb1", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+    output$untable1 <- renderDT({
+      tb = out_untb1()$table
+      cap = out_untb1()$caption
+      out.tb1 = datatable(tb, rownames = T, extensions = "Buttons", caption = cap,
+                          options = c(jstable::opt.tb1("tb1"),
+                                      list(columnDefs = list(list(visible=FALSE, targets= which(colnames(tb) %in% c("test","sig"))))
+                                      ),
+                                      list(scrollX = TRUE)
+                          )
+      )
+      if ("sig" %in% colnames(tb)){
+        out.tb1 = out.tb1 %>% formatStyle("sig", target = 'row' ,backgroundColor = styleEqual("**", 'yellow'))
+      }
+      return(out.tb1)
+    })
+
+    out_tb1 <- callModule(tb1module2, "tb1", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
+
+    output$table1 <- renderDT({
+      tb = out_tb1()$table
+      cap = out_tb1()$caption
+      out.tb1 = datatable(tb, rownames = T, extensions= "Buttons", caption = cap,
+                          options = c(opt.tb1("tb1"),
+                                      list(columnDefs = list(list(visible=FALSE, targets= which(colnames(tb) %in% c("test","sig"))))
+                                      ),
+                                      list(scrollX = TRUE)
+                          )
+      )
+      if ("sig" %in% colnames(tb)){
+        out.tb1 = out.tb1 %>% formatStyle("sig", target = 'row' ,backgroundColor = styleEqual("**", 'yellow'))
+      }
+      return(out.tb1)
+    })
+
+    out_linear <- callModule(regressModule2, "linear", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, default.unires = F, nfactor.limit = nfactor.limit)
+
+    output$lineartable <- renderDT({
+      hide = which(colnames(out_linear()$table) == "sig")
+      datatable(out_linear()$table, rownames=T, extensions= "Buttons", caption = out_linear()$caption,
+                options = c(opt.tbreg(out_linear()$caption),
+                            list(columnDefs = list(list(visible=FALSE, targets =hide))
+                            ),
+                            list(scrollX = TRUE)
+                )
+      ) %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+    })
+
+    out_logistic <- callModule(logisticModule2, "logistic", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, default.unires = F, nfactor.limit = nfactor.limit)
+
+    output$logistictable <- renderDT({
+      hide = which(colnames(out_logistic()$table) == "sig")
+      datatable(out_logistic()$table, rownames=T, extensions= "Buttons", caption = out_logistic()$caption,
+                options = c(opt.tbreg(out_logistic()$caption),
+                            list(columnDefs = list(list(visible=FALSE, targets =hide))
+                            ),
+                            list(scrollX = TRUE)
+                )
+      ) %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+    })
+
+    out_cox <- callModule(coxModule, "cox", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, default.unires = F, nfactor.limit = nfactor.limit)
+
+    output$coxtable <- renderDT({
+      hide = which(colnames(out_cox()$table) == c("sig"))
+      datatable(out_cox()$table, rownames=T, extensions= "Buttons", caption = out_cox()$caption,
+                options = c(opt.tbreg(out_cox()$caption),
+                            list(columnDefs = list(list(visible=FALSE, targets= hide))
+                            )
+                )
+      )  %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+    })
+
+
+    out_ggpairs <- callModule(ggpairsModule2, "ggpairs", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$ggpairs_plot <- renderPlot({
+      print(out_ggpairs())
+    })
+
+    out_kaplan <- callModule(kaplanModule, "kaplan", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
+
+    output$kaplan_plot <- renderPlot({
+      print(out_kaplan())
+    })
+
+    out_roc <- callModule(rocModule, "roc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
+
+    output$plot_roc <- renderPlot({
+      print(out_roc()$plot)
+    })
+
+    output$table_roc <- renderDT({
+      datatable(out_roc()$tb, rownames=F, editable = F, extensions= "Buttons",
+                caption = "ROC results",
+                options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
+    })
+
+    out_timeroc <- callModule(timerocModule, "timeroc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey, nfactor.limit = nfactor.limit)
+
+    output$plot_timeroc <- renderPlot({
+      print(out_timeroc()$plot)
+    })
+
+    output$table_timeroc <- renderDT({
+      datatable(out_timeroc()$tb, rownames=F, editable = F, extensions= "Buttons", caption = "ROC results",
+                options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
+    })
+
+  }
+
+  #viewer <- dialogViewer("Descriptive statistics", width = 1100, height = 850)
+  viewer <- browserViewer(browser = getOption("browser"))
+  runGadget(ui, server, viewer = viewer)
+
+
+  }
