@@ -114,6 +114,7 @@ regressModuleUI <- function(id) {
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey survey data. default: NULL
 #' @param default.unires Set default independent variables using univariate analysis, Default: T
+#' @param limit.unires Change to default.unires = F if number of independent variables > limit.unires, Default: 20
 #' @return Shiny modulde server for linear regression.
 #' @details Shiny modulde server for linear regression.
 #' @examples
@@ -151,7 +152,7 @@ regressModuleUI <- function(id) {
 #' @importFrom jstable LabelepiDisplay
 #' @importFrom purrr map_lgl
 
-regressModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T) {
+regressModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, limit.unires = 20) {
 
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
@@ -199,10 +200,12 @@ regressModule <- function(input, output, session, data, data_label, data_varStru
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            coef <- summary(glm(forms, data =data))$coefficients
-                            sigOK <- !all(coef[-1, "Pr(>|t|)"] > 0.05)
+                            coef <- tryCatch(summary(glm(forms, data = data))$coefficients, error = function(e){return(NULL)})
+                            #coef <- summary(glm(forms, data = data()))$coefficients
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, "Pr(>|t|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) -1))
       }
@@ -213,11 +216,11 @@ regressModule <- function(input, output, session, data, data_label, data_varStru
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            #data.design <- survey::svydesign(ids = ~ 1, data = data(), weights = ~ get(var.weights.survey()))
-                            coef <- summary(survey::svyglm(forms, design = design.survey))$coefficients
-                            sigOK <- !all(coef[-1, "Pr(>|t|)"] > 0.05)
+                            coef <- tryCatch(summary(survey::svyglm(forms, design = design.survey))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, "Pr(>|t|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) -1))
       }
@@ -345,6 +348,7 @@ regressModule <- function(input, output, session, data, data_label, data_varStru
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey reactive survey data. default: NULL
 #' @param default.unires Set default independent variables using univariate analysis, Default: T
+#' @param limit.unires Change to default.unires = F if number of independent variables > limit.unires, Default: 20
 #' @return Shiny modulde server for linear regression.
 #' @details Shiny modulde server for linear regression.
 #' @examples
@@ -381,7 +385,7 @@ regressModule <- function(input, output, session, data, data_label, data_varStru
 #' @importFrom epiDisplay regress.display
 #' @importFrom purrr map_lgl
 
-regressModule2 <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T) {
+regressModule2 <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, limit.unires = 20) {
 
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
@@ -450,10 +454,12 @@ regressModule2 <- function(input, output, session, data, data_label, data_varStr
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            coef <- summary(glm(forms, data = data()))$coefficients
-                            sigOK <- !all(coef[-1, "Pr(>|t|)"] > 0.05)
+                            coef <- tryCatch(summary(glm(forms, data = data()))$coefficients, error = function(e){return(NULL)})
+                            #coef <- summary(glm(forms, data = data()))$coefficients
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, "Pr(>|t|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) -1))
       }
@@ -464,11 +470,12 @@ regressModule2 <- function(input, output, session, data, data_label, data_varStr
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            #data.design <- survey::svydesign(ids = ~ 1, data = data(), weights = ~ get(var.weights.survey()))
-                            coef <- summary(survey::svyglm(forms, design = design.survey()))$coefficients
-                            sigOK <- !all(coef[-1, "Pr(>|t|)"] > 0.05)
+                            coef <- tryCatch(summary(survey::svyglm(forms, design = design.survey()))$coefficients, error = function(e){return(NULL)})
+                            #coef <- summary(survey::svyglm(forms, design = design.survey()))$coefficients
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, "Pr(>|t|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) -1))
       }
@@ -644,6 +651,7 @@ regressModule2 <- function(input, output, session, data, data_label, data_varStr
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey survey data. default: NULL
 #' @param default.unires Set default independent variables using univariate analysis, Default: T
+#' @param limit.unires Change to default.unires = F if number of independent variables > limit.unires, Default: 20
 #' @return Shiny modulde server for logistic regression.
 #' @details Shiny modulde server for logistic regression.
 #' @examples
@@ -681,7 +689,7 @@ regressModule2 <- function(input, output, session, data, data_label, data_varStr
 #' @importFrom jstable LabelepiDisplay
 #' @importFrom purrr map_lgl
 
-logisticModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T) {
+logisticModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, limit.unires = 20) {
 
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
@@ -731,10 +739,13 @@ logisticModule <- function(input, output, session, data, data_label, data_varStr
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            coef <- summary(glm(forms, data = data(), family = binomial))$coefficients
-                            sigOK <- !all(coef[-1, 4] > 0.05)
+                            coef <- tryCatch(summary(glm(forms, data = data, family = binomial))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, 4] > 0.05))
+                            #coef <- summary(glm(forms, data = data(), family = binomial))$coefficients
+                            #sigOK <- !all(coef[-1, 4] > 0.05)
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars)-1))
       }
@@ -745,11 +756,11 @@ logisticModule <- function(input, output, session, data, data_label, data_varStr
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            #data.design <- survey::svydesign(ids = ~ 1, data = data(), weights = ~ get(var.weights.survey))
-                            coef <- summary(survey::svyglm(forms, design = design.survey, family = binomial))$coefficients
-                            sigOK <- !all(coef[-1, 4] > 0.05)
+                            coef <- tryCatch(summary(survey::svyglm(forms, design = design.survey, family = binomial))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, 4] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars)-1))
       }
@@ -872,6 +883,7 @@ logisticModule <- function(input, output, session, data, data_label, data_varStr
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey reactive survey data. default: NULL
 #' @param default.unires Set default independent variables using univariate analysis, Default: T
+#' @param limit.unires Change to default.unires = F if number of independent variables > limit.unires, Default: 20
 #' @return Shiny modulde server for logistic regression.
 #' @details Shiny modulde server for logistic regression.
 #' @examples
@@ -909,7 +921,7 @@ logisticModule <- function(input, output, session, data, data_label, data_varStr
 #' @importFrom purrr map_lgl
 
 
-logisticModule2 <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T) {
+logisticModule2 <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, limit.unires = 20) {
 
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
@@ -975,10 +987,11 @@ logisticModule2 <- function(input, output, session, data, data_label, data_varSt
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            coef <- summary(glm(forms, data = data(), family = binomial))$coefficients
-                            sigOK <- !all(coef[-1, 4] > 0.05)
+                            coef <- tryCatch(summary(glm(forms, data = data(), family = binomial))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, 4] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) - 1))
       }
@@ -989,11 +1002,12 @@ logisticModule2 <- function(input, output, session, data, data_label, data_varSt
         varsIni <- sapply(vars,
                           function(v){
                             forms <- as.formula(paste(input$dep_vars, "~", v))
-                            #data.design <- survey::svydesign(ids = ~ 1, data = data(), weights = ~ get(var.weights.survey()))
-                            coef <- summary(survey::svyglm(forms, design = design.survey(), family = binomial))$coefficients
-                            sigOK <- !all(coef[-1, 4] > 0.05)
+                            coef <- tryCatch(summary(survey::svyglm(forms, design = design.survey(), family = binomial))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[-1, 4] > 0.05))
+
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(vars) -1))}
       } else{
         varsIni <- c(T, rep(F, length(vars) - 1))
       }
